summaryrefslogtreecommitdiff
path: root/lisp/leim
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2014-01-15 22:24:06 -0800
committerPaul Eggert <eggert@cs.ucla.edu>2014-01-15 22:24:06 -0800
commitc91c771dbe242cd942c00a0a57c18c1482e59fa0 (patch)
treeabb6fcaf49f4bda5eda2443fb5a6f7531a8a2a74 /lisp/leim
parent7da02a6769e84cd0a9df8b1bc18ac78df1c0b058 (diff)
downloademacs-c91c771dbe242cd942c00a0a57c18c1482e59fa0.tar.gz
Spelling fixes.
Diffstat (limited to 'lisp/leim')
-rw-r--r--lisp/leim/quail/ipa-praat.el4
-rw-r--r--lisp/leim/quail/ipa.el2
2 files changed, 3 insertions, 3 deletions
diff --git a/lisp/leim/quail/ipa.el b/lisp/leim/quail/ipa.el
index fd283be7670..322f34ad33e 100644
--- a/lisp/leim/quail/ipa.el
+++ b/lisp/leim/quail/ipa.el
@@ -440,7 +440,7 @@ displays them, incorrectly, as separate from the modified glyphs.")
(">\\" "ʡ") ;; Epiglottal plosive U+02A1
("^" "↑") ;; Upstep U+2191
("!" "↓") ;; Downstep U+2193
- ("!\\" "ǃ") ;; Postalveolal click U+01C3
+ ("!\\" "ǃ") ;; Postalveolar click U+01C3
("\\" "ǀ") ;; Dental click U+01C0
("\\|\\" "ǁ") ;; Lateral alveolar click U+01C1
("=\\" "ǂ") ;; Palatal click U+01C2
diff --git a/lisp/leim/quail/ipa-praat.el b/lisp/leim/quail/ipa-praat.el
index c5156ad892b..53229724ae3 100644
--- a/lisp/leim/quail/ipa-praat.el
+++ b/lisp/leim/quail/ipa-praat.el
@@ -23,7 +23,7 @@
;;; Commentary:
;; This is a new input method for IPA characters and diacritics, which follows
;; the conventions of Praat, a GPLed program for phonetical analysis.
;;
;; This input method is much more complete than the current ipa.el.
@@ -34,7 +34,7 @@
(quail-define-package
"ipa-praat" "IPA" "IPAP" t
"International Phonetic Alphabet input method.
-This follows the input method of the phonetical analysis program
+This follows the input method of the phonetic analysis program
Praat (http://www.fon.hum.uva.nl/praat/).
@@ -23,7 +23,7 @@
;;; Commentary:
;; This is a new input method for IPA characters and diacritics, which follows
-;; the conventions of Praat, a GPLed program for phonetical analysis.
+;; the conventions of Praat, a GPLed program for phonetic analysis.
;;
;; This input method is much more complete than the current ipa.el.